@@ -58,23 +58,22 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': [self.mock_policy]}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
                      append=['v2.0', 'qos', 'policies', self.policy_id,
-                             'dscp_marking_rules',
-                             '%s.json' % self.rule_id]),
+                             'dscp_marking_rules', self.rule_id]),
                  json={'dscp_marking_rule': self.mock_rule})
         ])
         r = self.cloud.get_qos_dscp_marking_rule(self.policy_name,
@@ -86,16 +85,16 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': []})
         ])
         self.assertRaises(
@@ -108,7 +107,7 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': []})
         ])
         self.assertRaises(
@@ -121,16 +120,16 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': [self.mock_policy]}),
             dict(method='POST',
                  uri=self.get_mock_url(
@@ -148,7 +147,7 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': []})
         ])
         self.assertRaises(
@@ -164,43 +163,41 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': [self.mock_policy]}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': [self.mock_policy]}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
                      append=['v2.0', 'qos', 'policies', self.policy_id,
-                             'dscp_marking_rules',
-                             '%s.json' % self.rule_id]),
+                             'dscp_marking_rules', self.rule_id]),
                  json={'dscp_marking_rule': self.mock_rule}),
             dict(method='PUT',
                  uri=self.get_mock_url(
                      'network', 'public',
                      append=['v2.0', 'qos', 'policies', self.policy_id,
-                             'dscp_marking_rules',
-                             '%s.json' % self.rule_id]),
+                             'dscp_marking_rules', self.rule_id]),
                  json={'dscp_marking_rule': expected_rule},
                  validate=dict(
                      json={'dscp_marking_rule': {
@@ -215,7 +212,7 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': []})
         ])
         self.assertRaises(
@@ -228,23 +225,23 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': [self.mock_policy]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
                      append=['v2.0', 'qos', 'policies', self.policy_id,
                              'dscp_marking_rules',
-                             '%s.json' % self.rule_id]),
+                             self.rule_id]),
                  json={})
         ])
         self.assertTrue(
@@ -256,7 +253,7 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': []})
         ])
         self.assertRaises(
@@ -269,23 +266,22 @@ class TestQosDscpMarkingRule(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'qos', 'policies.json']),
+                     append=['v2.0', 'qos', 'policies']),
                  json={'policies': [self.mock_policy]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
                      append=['v2.0', 'qos', 'policies', self.policy_id,
-                             'dscp_marking_rules',
-                             '%s.json' % self.rule_id]),
+                             'dscp_marking_rules', self.rule_id]),
                  status_code=404)
         ])
         self.assertFalse(
