@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 import uuid
 
 import testtools
@@ -54,13 +54,60 @@ class TestShade(base.TestCase):
     def test_openstack_cloud(self):
         self.assertIsInstance(self.cloud, connection.Connection)
 
+    def test_endpoint_for(self):
+        dns_override = 'https://override.dns.example.com'
+        self.cloud.config.config['dns_endpoint_override'] = dns_override
+        self.assertEqual(
+            'https://compute.example.com/v2.1/',
+            self.cloud.endpoint_for('compute'))
+        self.assertEqual(
+            'https://internal.compute.example.com/v2.1/',
+            self.cloud.endpoint_for('compute', interface='internal'))
+        self.assertIsNone(
+            self.cloud.endpoint_for('compute', region_name='unknown-region'))
+        self.assertEqual(
+            dns_override,
+            self.cloud.endpoint_for('dns'))
+
     def test_connect_as(self):
         # Do initial auth/catalog steps
-        # TODO(mordred) This only tests the constructor steps. Discovery
-        # cache sharing is broken. We need to get discovery_cache option
-        # plumbed through
-        # keystoneauth1.loading.base.BaseLoader.load_from_options
-        self.cloud.connect_as(project_name='test_project')
+        # This should authenticate a second time, but should not
+        # need a second identity discovery
+        project_name = 'test_project'
+        self.register_uris([
+            self.get_keystone_v3_token(project_name=project_name),
+            self.get_nova_discovery_mock_dict(),
+            dict(
+                method='GET',
+                uri=self.get_mock_url(
+                    'compute', 'public', append=['servers', 'detail']),
+                json={'servers': []},
+            ),
+        ])
+
+        c2 = self.cloud.connect_as(project_name=project_name)
+        self.assertEqual(c2.list_servers(), [])
+        self.assert_calls()
+
+    def test_connect_as_context(self):
+        # Do initial auth/catalog steps
+        # This should authenticate a second time, but should not
+        # need a second identity discovery
+        project_name = 'test_project'
+        self.register_uris([
+            self.get_keystone_v3_token(project_name=project_name),
+            self.get_nova_discovery_mock_dict(),
+            dict(
+                method='GET',
+                uri=self.get_mock_url(
+                    'compute', 'public', append=['servers', 'detail']),
+                json={'servers': []},
+            ),
+        ])
+
+        with self.cloud.connect_as(project_name=project_name) as c2:
+            self.assertEqual(c2.list_servers(), [])
+        self.assert_calls()
 
     @mock.patch.object(connection.Connection, 'search_images')
     def test_get_images(self, mock_search):
@@ -76,6 +123,44 @@ class TestShade(base.TestCase):
         r = self.cloud.get_image('doesNotExist')
         self.assertIsNone(r)
 
+    def test_global_request_id(self):
+        request_id = uuid.uuid4().hex
+        self.register_uris([
+            self.get_nova_discovery_mock_dict(),
+            dict(
+                method='GET',
+                uri=self.get_mock_url(
+                    'compute', 'public', append=['servers', 'detail']),
+                json={'servers': []},
+                validate=dict(
+                    headers={'X-Openstack-Request-Id': request_id}),
+            ),
+        ])
+
+        cloud2 = self.cloud.global_request(request_id)
+        self.assertEqual([], cloud2.list_servers())
+
+        self.assert_calls()
+
+    def test_global_request_id_context(self):
+        request_id = uuid.uuid4().hex
+        self.register_uris([
+            self.get_nova_discovery_mock_dict(),
+            dict(
+                method='GET',
+                uri=self.get_mock_url(
+                    'compute', 'public', append=['servers', 'detail']),
+                json={'servers': []},
+                validate=dict(
+                    headers={'X-Openstack-Request-Id': request_id}),
+            ),
+        ])
+
+        with self.cloud.global_request(request_id) as c2:
+            self.assertEqual([], c2.list_servers())
+
+        self.assert_calls()
+
     def test_get_server(self):
         server1 = fakes.make_fake_server('123', 'mickey')
         server2 = fakes.make_fake_server('345', 'mouse')
@@ -122,26 +207,10 @@ class TestShade(base.TestCase):
 
         self.assert_calls()
 
-    def test__neutron_exceptions_resource_not_found(self):
-        self.register_uris([
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
-                 status_code=404)
-        ])
-        self.assertRaises(exc.OpenStackCloudResourceNotFound,
-                          self.cloud.list_networks)
-        self.assert_calls()
-
-    def test__neutron_exceptions_url_not_found(self):
-        self.register_uris([
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
-                 status_code=404)
-        ])
-        self.assertRaises(exc.OpenStackCloudURINotFound,
-                          self.cloud.list_networks)
+    def test_neutron_not_found(self):
+        self.use_nothing()
+        self.cloud.has_service = mock.Mock(return_value=False)
+        self.assertEqual([], self.cloud.list_networks())
         self.assert_calls()
 
     def test_list_servers(self):
@@ -340,11 +409,11 @@ class TestShade(base.TestCase):
                  json={'servers': [fake_server]}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json=fake_networks),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'subnets.json']),
+                     'network', 'public', append=['v2.0', 'subnets']),
                  json=fake_subnets)
         ])
 
@@ -552,7 +621,7 @@ class TestShade(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json=dict(extensions=body))
         ])
         extensions = self.cloud._neutron_extensions()
@@ -564,7 +633,7 @@ class TestShade(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  status_code=404)
         ])
         with testtools.ExpectedException(
@@ -596,7 +665,7 @@ class TestShade(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json=dict(extensions=body))
         ])
         self.assertTrue(self.cloud._has_neutron_extension('dvr'))
@@ -623,7 +692,7 @@ class TestShade(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json=dict(extensions=body))
         ])
         self.assertFalse(self.cloud._has_neutron_extension('invalid'))
